# pyttsgen/config.py

# Define a dictionary of voices with identifiers.
VOICES = {
    "American - Aria": "en-US-AriaNeural",
    "American - Guy": "en-US-GuyNeural",
    "British - Libby": "en-GB-LibbyNeural",
    "Australian - Natasha": "en-AU-NatashaNeural",
    "British - Ryan": "en-GB-RyanNeural"
}

DEFAULT_VOICE = VOICES["American - Aria"]
